function [TalphaPlus,TindMUr,Tsigma2r,TR]= unmixing(y,Nmc)

%------------------------------------------------------------------
% % SPECTRAL UNMIXING
% % by O. ECHES, N. DOBIGEON and J.-Y. TOURNERET 
% % IRIT/ENSEEIHT/TSA - France - 2007
% 
% INPUT
%       y        : the pixel to be unmixed
%       Nmc      : number of MCMC iterations
%
% OUTPUT
%       TalphaPlus : the samples \alpha^+ generated by the procedure
%       TindMUr  : the samples of the index spectra estimated by the reversible jump procedure       
%       TR : the samples R estimated by the reversible jump procedure 
%       Tsigma2r : the samples \sigma_r^2 generated by the procedure
%
%------------------------------------------------------------------

load library
global L Rmax 
% number of spectral bands x number of endmember spectra
[L Rmax] = size(lib_spectra);


% initialization of the parameters

% Spectra to be chosen in the library
ind = [4 5 6 2 1 3];

MUr = lib_spectra(:,ind);

R = length(ind);

%hyperparameter : delta
delta = 1;

sigma2r = 0.2*ones(R,1);

alphaPlus = ones(R,1)/R;
TalphaPlus = zeros(Rmax,Nmc);
Tsigma2r = zeros(1,Nmc);
TindMUr = zeros(Rmax,Nmc);
TR = zeros(1,Nmc);
Trho = zeros(R,Nmc);
sig = 5e-2*ones(1,R);
Tx = 0.3*ones(R,1);

% probability of the jumps used in the RJ-MCMC
proba_b = [1/2 ones(1,Rmax-2)/3  0 ];
proba_d = [ 0  ones(1,Rmax-2)/3 1/2];
proba_u = 1-(proba_b+proba_d);
proba_bdu = [proba_b; proba_d; proba_u];
t = 0.02;

h = waitbar(0,'Sampling...','CreateCancelBtn','closereq', 'name', 'UNMIXING...');

% beginning
for m_compt=1:Nmc
    
    waitbar(m_compt/Nmc,h)
    
    %RJ-MCMC
    [alphaPlus,ind,R,sigma2r] = reversible_jump(y,R,ind,MUr,alphaPlus,sigma2r,proba_bdu);

    % correction to remove the negligible abundances coefficients
    [R, alphaPlus, ind, sigma2r] = correction(R, alphaPlus, sigma2r, ind, t);
    
    TR(:,m_compt)=R;
    MUr = lib_spectra(:,ind);
    TindMUr(1:R,m_compt) = ind;

    % updating the abundance coefficients
    % sig : variances for the random walk Gaussian distribution
    % rho : useful variable 
    [alphaPlus, rho,sig] = sample_alphaPlus(alphaPlus,y,MUr,sigma2r,R,m_compt,Tx(ind,:),sig)   ; 

    TalphaPlus(ind,m_compt) = alphaPlus; 
    Trho(ind,m_compt) = rho;

   if rem(m_compt,100) == 0 
    % abundance vector acceptance rate for every 100 iterations
       Tx = mean(Trho(:,m_compt-99:m_compt),2);
   end    
   
   % updating the endmember variance
      sigma2r = sample_sigma2r(alphaPlus, MUr, y, delta, R);
      sigma2r = kron(sigma2r,ones(R,1));
      
    Tsigma2r(1,m_compt) = sigma2r(1);
    
   % updating the hyperparameter
   delta = gamrnd(R,inv(sum(1./sigma2r)));

end

close(h)
